#!/bin/sh

. /lib/security-functions.sh

exec 2>/dev/null

clear

grep -q  $securityfs_mnt /proc/mounts || mount -n -t securityfs securityfs $securityfs_mnt

kic_status_path="$securityfs_mnt/kic/status"

kic_is_enabled()
{
	if [ -e "$kic_status_path" ]; then
		cat "$kic_status_path"
	else
		echo 0
	fi
}

kic_enabled=`kic_is_enabled`
if [ 0 -eq "$kic_enabled" ]; then
	info "KIC disabled "
	return 0
fi

kic_conf=${NEWROOT}/usr/share/kic-utils/system_label

set_kic_label_all()
{
	local filelist=$1
	if [ -f "$filelist" ]; then
		cat "$filelist" | while read line
		do
			local gtmp=${line##* }
			local glabel=${gtmp%%[*}
			local atmp=${gtmp##*[}
			local alabel=${atmp%%]*}
			local filename=${line%% *}

			if [ $atmp = $alabel ]; then
				find "${NEWROOT}$filename" -exec setfattr -n security.kic -v "kic/"$glabel '{}' \;
			else
				find "${NEWROOT}$filename" -exec setfattr -n security.kic -v "kic/"$glabel"["$alabel"]" '{}' \;
			fi
		done
	else
		echo "The configurefile ($1) is not exist!"
	fi
}

kic_do_remount()
{
	mount -o remount,rw ${root_device} ${NEWROOT}
	mount -t proc -o nodev,noexec,nosuid proc "$NEWROOT/proc"
	mount -t sysfs -o nodev,noexec,nosuid sys "$NEWROOT/sys"
	mount -t devtmpfs udev "$NEWROOT/dev"

	chroot "${NEWROOT}" /bin/mount -a

	set_kic_label_all "$kic_conf"

	umount "$NEWROOT/proc"
	umount "$NEWROOT/sys"
	umount "$NEWROOT/dev"

	if [ -e ${NEWROOT}/.kic_relabel ]; then
		rm -rf ${NEWROOT}/.kic_relabel
	fi
}

export kic_relabel=

for x in $(cat /proc/cmdline); do
	case $x in
	kic_relabel=*)
		kic_relabel=${x#kic_relabel=}
		;;
	esac
done

if [ "x${kic_relabel}" = "x1" -o -e ${NEWROOT}/.kic_relabel ]; then
	show_message "KIC relabel is required"
	show_message "正在初始化系统KIC安全标记，请稍候．．．"
	kic_do_remount
	clear_message
fi

clear
